# The address of the message broker. All workers and clients use the same URL.
BROKER_URL = 'redis://localhost'

# Using redis as result backend. Again, this URL should be the same for all
# workers and clients.
CELERY_RESULT_BACKEND = 'redis://localhost'

# Use json because it is available everywhere.
# msgpack can save bandwidth and performance when available.
# pickle is a security risk but more powerful than json.
CELERY_TASK_SERIALIZER = 'json'
CELERY_RESULT_SERIALIZER = 'json'
CELERY_ACCEPT_CONTENT = ['json']

# We are not interested in limiting the execution rate of tasks.
CELERY_DISABLE_RATE_LIMITS = True

# Use the "STARTED" state for tasks.
CELERY_TRACK_STARTED = True

# Create a new worker process for every task.
# This helps in case of memory leaks, performance impact should be marginal as
# our tasks usually run for a long time.
CELERYD_MAX_TASKS_PER_CHILD = 1

# Results are needed to inspect the outcome of a plugin task.
# We keep results/states cached for 24 days, unless cleared manually.
# Note that results become difficult or impossible to retrieve if the worker is
# stopped.
CELERY_TASK_RESULT_EXPIRES = 2147483

# Configure logging so just stdout/stderr is written to the output files.
CELERYD_TASK_LOG_FORMAT = '%(message)s'
CELERYD_LOG_COLOR = False

# No (effective) visibility timeout when using redis. When this value is too
# low, tasks that wait a long time in the queue will be executed multiple times.
BROKER_TRANSPORT_OPTIONS = {'visibility_timeout': 1073741824}
